var searchData=
[
  ['b_0',['b',['../structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a0bf5cd03cd38b5b8a21edc450e3ab2ce',1,'libcamera::DebayerParams::CcmColumn::b'],['../classlibcamera_1_1Vector.html#a0f5cdc92b62075308772ba61b4a3fbcf',1,'libcamera::Vector::b() const'],['../classlibcamera_1_1Vector.html#a29055157486dce081d2be29ff7308dd0',1,'libcamera::Vector::b()']]],
  ['backtrace_1',['Backtrace',['../classlibcamera_1_1Backtrace.html',1,'libcamera::Backtrace'],['../classlibcamera_1_1Backtrace.html#a330b7c9133d7c7c8e4a03e6f9d668caf',1,'libcamera::Backtrace::Backtrace()']]],
  ['backtrace_2',['backtrace',['../classlibcamera_1_1Logger.html#adb8344666236c0db52a5de8dfdaf69bd',1,'libcamera::Logger']]],
  ['backtrace_2eh_3',['backtrace.h',['../backtrace_8h.html',1,'']]],
  ['base_4',['base',['../classlibcamera_1_1ByteStreamBuffer.html#a7b3acb185a57d6a90308e140e0841e11',1,'libcamera::ByteStreamBuffer']]],
  ['basename_5',['basename',['../utils_8h.html#a1d2c8b994fc3be2a2ed92eca41e17d79',1,'libcamera::utils']]],
  ['bayer_5fformat_2eh_6',['bayer_format.h',['../bayer__format_8h.html',1,'']]],
  ['bayerformat_7',['BayerFormat',['../classlibcamera_1_1BayerFormat.html',1,'libcamera::BayerFormat'],['../classlibcamera_1_1BayerFormat.html#add4b672542165a208e519dd2c90a2f0a',1,'libcamera::BayerFormat::BayerFormat()'],['../classlibcamera_1_1BayerFormat.html#aa74dedaa9831b8a5fd11da3eaa69a0ac',1,'libcamera::BayerFormat::BayerFormat(Order o, uint8_t b, Packing p)']]],
  ['bayerorder_8',['bayerOrder',['../classlibcamera_1_1CameraSensor.html#a356c31644de465032fdbe7473515ca51',1,'libcamera::CameraSensor']]],
  ['bcm2835statsoutput_9',['Bcm2835StatsOutput',['../namespacelibcamera_1_1controls_1_1rpi.html#a9a8abf34401511f54e8eb4ac0e47b90e',1,'libcamera::controls::rpi']]],
  ['bdsgrid_10',['bdsGrid',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPASessionConfiguration.html#a082d2ac088aaf8920c1b945db0b4dfa9',1,'libcamera::ipa::ipu3::IPASessionConfiguration']]],
  ['bdsoutputsize_11',['bdsOutputSize',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPASessionConfiguration.html#aac6854fd0181e4d87cf1ed1b47da95ab',1,'libcamera::ipa::ipu3::IPASessionConfiguration']]],
  ['begin_12',['begin',['../classlibcamera_1_1CameraConfiguration.html#aa2ddb8bb3793882bc933df408d36d726',1,'libcamera::CameraConfiguration::begin()'],['../classlibcamera_1_1CameraConfiguration.html#a6450b3c3e63919bdab08e0ee23b37370',1,'libcamera::CameraConfiguration::begin() const'],['../classlibcamera_1_1ControlList.html#aa8e6bf28f79e8ad014270dd24a5cb81f',1,'libcamera::ControlList::begin()'],['../classlibcamera_1_1ControlList.html#ad9c5294f02555d1773a1bc08142ba913',1,'libcamera::ControlList::begin() const']]],
  ['bggr_13',['BGGR',['../classlibcamera_1_1BayerFormat.html#a72f709c68ce975ab0cbfc65cc5a73b95a28619ddc84e36356d2adfff20b8340b1',1,'libcamera::BayerFormat::BGGR'],['../namespacelibcamera_1_1properties_1_1draft.html#ae4dac9d6f57db34b666c70f88196e092a8b8e1c9f9e3e3db468b0ea15fe6d2600',1,'libcamera::properties::draft::BGGR']]],
  ['binarysize_14',['binarySize',['../classlibcamera_1_1ControlSerializer.html#a1dd33ddfa20b84fbc37fbd876769e8c3',1,'libcamera::ControlSerializer::binarySize(const ControlInfoMap &amp;infoMap)'],['../classlibcamera_1_1ControlSerializer.html#aa82f73722342b25fc7de6eb11691b838',1,'libcamera::ControlSerializer::binarySize(const ControlList &amp;list)']]],
  ['bind_15',['bind',['../classlibcamera_1_1IPCUnixSocket.html#a9c11dc2c41bc3e3047d66f37bd6f84a6',1,'libcamera::IPCUnixSocket']]],
  ['binning_16',['binning',['../classlibcamera_1_1SensorConfiguration.html#a649689c113b428925e495d45ebab288b',1,'libcamera::SensorConfiguration']]],
  ['bins_17',['bins',['../classlibcamera_1_1ipa_1_1Histogram.html#a3ff35a7464ce6b028f720dd528e4ea26',1,'libcamera::ipa::Histogram']]],
  ['binx_18',['binX',['../classlibcamera_1_1SensorConfiguration.html#aa58c69d3e7700b1ce68127d8b940d64f',1,'libcamera::SensorConfiguration']]],
  ['biny_19',['binY',['../classlibcamera_1_1SensorConfiguration.html#ac9fbf0697794b540e4e5714ec7877c81',1,'libcamera::SensorConfiguration']]],
  ['bitdepth_20',['bitDepth',['../classlibcamera_1_1SensorConfiguration.html#a1f62a69a221a0aff2d60d585618b3d30',1,'libcamera::SensorConfiguration::bitDepth'],['../classlibcamera_1_1BayerFormat.html#a344721940ef68a7db49171703d966dfc',1,'libcamera::BayerFormat::bitDepth']]],
  ['bitsperpixel_21',['bitsPerPixel',['../classlibcamera_1_1PixelFormatInfo.html#a4d1d04fd5977357b10747388a6441e7b',1,'libcamera::PixelFormatInfo::bitsPerPixel'],['../classlibcamera_1_1MediaBusFormatInfo.html#aa8ac57fc34eb05f61f0b65d2c728ecf6',1,'libcamera::MediaBusFormatInfo::bitsPerPixel'],['../structlibcamera_1_1IPACameraSensorInfo.html#aade1f3bd6e1d04666746d157382d6a23',1,'libcamera::IPACameraSensorInfo::bitsPerPixel']]],
  ['blacklevel_22',['blackLevel',['../classlibcamera_1_1ipa_1_1CameraSensorHelper.html#a50b83c557290bb14509fc93ade4c6765',1,'libcamera::ipa::CameraSensorHelper']]],
  ['blacklevel_5f_23',['blackLevel_',['../classlibcamera_1_1ipa_1_1CameraSensorHelper.html#a6bbe77cc220f5b4d8488d5f6b306c0d9',1,'libcamera::ipa::CameraSensorHelper']]],
  ['blacklevelcorrection_24',['BlackLevelCorrection',['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1BlackLevelCorrection.html',1,'libcamera::ipa::ipu3::algorithms']]],
  ['blc_2eh_25',['blc.h',['../blc_8h.html',1,'']]],
  ['blue_26',['blue',['../structlibcamera_1_1DebayerParams.html#a0111b2ccaa61e1f5e19095a752a8a5c0',1,'libcamera::DebayerParams::blue'],['../structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#ab1e6f5cca85d97dee2be4a951128f4ef',1,'libcamera::ipa::ipu3::algorithms::Accumulator::blue'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a1714e69dac816940e1ae455dbfbd6ab0',1,'libcamera::ipa::ipu3::IPAActiveState::blue']]],
  ['blueccm_27',['blueCcm',['../structlibcamera_1_1DebayerParams.html#a7067e64c2b77c1eff1854cf28d4009d2',1,'libcamera::DebayerParams']]],
  ['bound_28',['Bound',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html#a784f23cb354934b0615e2dbc75578759',1,'libcamera::ipa::AgcMeanLuminance::AgcConstraint']]],
  ['bound_29',['bound',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html#a9252318f96245592222f68eb3ce0238a',1,'libcamera::ipa::AgcMeanLuminance::AgcConstraint']]],
  ['bound_5fmethod_2eh_30',['bound_method.h',['../bound__method_8h.html',1,'']]],
  ['boundedto_31',['boundedTo',['../classlibcamera_1_1Size.html#a2094d73784a8aece896c364cc2bda5ca',1,'libcamera::Size::boundedTo()'],['../classlibcamera_1_1Rectangle.html#af6ab6db441d6ebb0c3032c0b26df243e',1,'libcamera::Rectangle::boundedTo()']]],
  ['boundedtoaspectratio_32',['boundedToAspectRatio',['../classlibcamera_1_1Size.html#ab44f288148efb162ba9d2d54cf844242',1,'libcamera::Size']]],
  ['boundto_33',['boundTo',['../classlibcamera_1_1Size.html#a29b267bc4fdc51c9b50a5cc7b98ae4ba',1,'libcamera::Size']]],
  ['bpl_34',['bpl',['../structlibcamera_1_1V4L2DeviceFormat_1_1Plane.html#a8e993f521224c108e3b4225d4d50fe4e',1,'libcamera::V4L2DeviceFormat::Plane']]],
  ['brightness_35',['Brightness',['../namespacelibcamera_1_1controls.html#ab2c40c5fe0916c0c1734fbb5b8e4faf2',1,'libcamera::controls']]],
  ['buffercompleted_36',['bufferCompleted',['../classlibcamera_1_1Camera.html#a5fe034be26009e8173b683db8e8fb80a',1,'libcamera::Camera']]],
  ['buffercount_37',['bufferCount',['../structlibcamera_1_1StreamConfiguration.html#a52204a14781dd3687657b790ba894e0a',1,'libcamera::StreamConfiguration']]],
  ['buffermap_38',['BufferMap',['../classlibcamera_1_1Request.html#a6ef726ce36fbc51d3ebd6e1d2366cd87',1,'libcamera::Request']]],
  ['bufferready_39',['bufferReady',['../classlibcamera_1_1V4L2VideoDevice.html#a549153ee5ea43d387aa4fa596f37b66e',1,'libcamera::V4L2VideoDevice']]],
  ['buffers_40',['buffers',['../classlibcamera_1_1FrameBufferAllocator.html#a8207ce42ed29ebae26378357c2054ee7',1,'libcamera::FrameBufferAllocator::buffers()'],['../classlibcamera_1_1Request.html#a24c7da0445dbb2bf61956a264e4c983e',1,'libcamera::Request::buffers()']]],
  ['bus_5finfo_41',['bus_info',['../structlibcamera_1_1V4L2Capability.html#a247346aef2cfc6df6c33750264798d05',1,'libcamera::V4L2Capability']]],
  ['busname_42',['busName',['../classlibcamera_1_1V4L2VideoDevice.html#a566391f6709ea9a07c3ce35199fcf5da',1,'libcamera::V4L2VideoDevice']]],
  ['busy_43',['busy',['../classlibcamera_1_1MediaDevice.html#a3f58c03f422e84824a9e2e35afcaa2bb',1,'libcamera::MediaDevice']]],
  ['byte_5fstream_5fbuffer_2eh_44',['byte_stream_buffer.h',['../byte__stream__buffer_8h.html',1,'']]],
  ['bytespergroup_45',['bytesPerGroup',['../structlibcamera_1_1PixelFormatInfo_1_1Plane.html#adceda8c9551a6d7475a0f1d31be97869',1,'libcamera::PixelFormatInfo::Plane']]],
  ['bytestreambuffer_46',['ByteStreamBuffer',['../classlibcamera_1_1ByteStreamBuffer.html',1,'libcamera::ByteStreamBuffer'],['../classlibcamera_1_1ByteStreamBuffer.html#aab08c12dd64a532b30e6606688a96d70',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(const uint8_t *base, size_t size)'],['../classlibcamera_1_1ByteStreamBuffer.html#abfa1e97f387a892b20ab201b74fe82c0',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(uint8_t *base, size_t size)'],['../classlibcamera_1_1ByteStreamBuffer.html#a15b0355a9b76b2cc9641ca228839000c',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(ByteStreamBuffer &amp;&amp;other)']]],
  ['bytesused_47',['bytesused',['../structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b',1,'libcamera::FrameMetadata::Plane']]]
];
